aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--include/render/gles2.h2
-rw-r--r--render/gles2/pixel_format.c18
-rw-r--r--render/gles2/renderer.c3
-rw-r--r--render/gles2/texture.c3
4 files changed, 15 insertions, 11 deletions
diff --git a/include/render/gles2.h b/include/render/gles2.h
index a2173fbb..00ee34fb 100644
--- a/include/render/gles2.h
+++ b/include/render/gles2.h
@@ -15,7 +15,7 @@
#include <wlr/util/log.h>
struct wlr_gles2_pixel_format {
- enum wl_shm_format wl_format;
+ uint32_t drm_format;
GLint gl_format, gl_type;
int depth, bpp;
bool has_alpha;
diff --git a/render/gles2/renderer.c b/render/gles2/renderer.c
index 4dafb328..cdf2c8b2 100644
--- a/render/gles2/renderer.c
+++ b/render/gles2/renderer.c
@@ -14,6 +14,7 @@
#include <wlr/types/wlr_linux_dmabuf_v1.h>
#include <wlr/util/log.h>
#include "render/gles2.h"
+#include "render/shm_format.h"
static const GLfloat verts[] = {
1, 0, // top right
@@ -455,7 +456,7 @@ static enum wl_shm_format gles2_preferred_read_format(
const struct wlr_gles2_pixel_format *fmt =
get_gles2_format_from_gl(gl_format, gl_type, alpha_size > 0);
if (fmt != NULL) {
- return fmt->wl_format;
+ return convert_drm_format_to_wl_shm(fmt->drm_format);
}
if (renderer->exts.read_format_bgra_ext) {
diff --git a/render/gles2/texture.c b/render/gles2/texture.c
index 41d71f3c..000333ce 100644
--- a/render/gles2/texture.c
+++ b/render/gles2/texture.c
@@ -11,6 +11,7 @@
#include <wlr/types/wlr_matrix.h>
#include <wlr/util/log.h>
#include "render/gles2.h"
+#include "render/shm_format.h"
#include "util/signal.h"
static const struct wlr_texture_impl texture_impl;
@@ -175,7 +176,7 @@ struct wlr_texture *gles2_texture_from_pixels(struct wlr_renderer *wlr_renderer,
texture->renderer = renderer;
texture->target = GL_TEXTURE_2D;
texture->has_alpha = fmt->has_alpha;
- texture->wl_format = fmt->wl_format;
+ texture->wl_format = convert_drm_format_to_wl_shm(fmt->drm_format);
struct wlr_egl_context prev_ctx;
wlr_egl_save_context(&prev_ctx);
diff --git a/render/gles2/pixel_format.c b/render/gles2/pixel_format.c
index 1258d8bc..c3eaa8e6 100644
--- a/render/gles2/pixel_format.c
+++ b/render/gles2/pixel_format.c
@@ -1,14 +1,16 @@
+#include <drm_fourcc.h>
#include <GLES2/gl2.h>
#include <GLES2/gl2ext.h>
#include "render/gles2.h"
+#include "render/shm_format.h"
/*
* The wayland formats are little endian while the GL formats are big endian,
* so WL_SHM_FORMAT_ARGB8888 is actually compatible with GL_BGRA_EXT.
*/
static const struct wlr_gles2_pixel_format formats[] = {
{
- .wl_format = WL_SHM_FORMAT_ARGB8888,
+ .drm_format = DRM_FORMAT_ARGB8888,
.depth = 32,
.bpp = 32,
.gl_format = GL_BGRA_EXT,
@@ -16,7 +18,7 @@ static const struct wlr_gles2_pixel_format formats[] = {
.has_alpha = true,
},
{
- .wl_format = WL_SHM_FORMAT_XRGB8888,
+ .drm_format = DRM_FORMAT_XRGB8888,
.depth = 24,
.bpp = 32,
.gl_format = GL_BGRA_EXT,
@@ -24,7 +26,7 @@ static const struct wlr_gles2_pixel_format formats[] = {
.has_alpha = false,
},
{
- .wl_format = WL_SHM_FORMAT_XBGR8888,
+ .drm_format = DRM_FORMAT_XBGR8888,
.depth = 24,
.bpp = 32,
.gl_format = GL_RGBA,
@@ -32,7 +34,7 @@ static const struct wlr_gles2_pixel_format formats[] = {
.has_alpha = false,
},
{
- .wl_format = WL_SHM_FORMAT_ABGR8888,
+ .drm_format = DRM_FORMAT_ABGR8888,
.depth = 32,
.bpp = 32,
.gl_format = GL_RGBA,
@@ -46,7 +48,7 @@ static const struct wlr_gles2_pixel_format formats[] = {
const struct wlr_gles2_pixel_format *get_gles2_format_from_wl(
enum wl_shm_format fmt) {
for (size_t i = 0; i < sizeof(formats) / sizeof(*formats); ++i) {
- if (formats[i].wl_format == fmt) {
+ if (convert_drm_format_to_wl_shm(formats[i].drm_format) == fmt) {
return &formats[i];
}
}
@@ -69,7 +71,7 @@ const enum wl_shm_format *get_gles2_wl_formats(size_t *len) {
static enum wl_shm_format wl_formats[sizeof(formats) / sizeof(formats[0])];
*len = sizeof(formats) / sizeof(formats[0]);
for (size_t i = 0; i < sizeof(formats) / sizeof(formats[0]); i++) {
- wl_formats[i] = formats[i].wl_format;
+ wl_formats[i] = convert_drm_format_to_wl_shm(formats[i].drm_format);
}
return wl_formats;
}
@@ -1,14 +1,16 @@
/*
- * The wayland formats are little endian while the GL formats are big endian,
- * so WL_SHM_FORMAT_ARGB8888 is actually compatible with GL_BGRA_EXT.
+ * The DRM formats are little endian while the GL formats are big endian,
+ * so DRM_FORMAT_ARGB8888 is actually compatible with GL_BGRA_EXT.
*/
static const struct wlr_gles2_pixel_format formats[] = {